@@ -4,8 +4,7 @@ import os
 import sys
 
 import stgit.main
-import stgit.version
-from stgit import argparse, commands
+from stgit import argparse, commands, get_version
 from stgit.completion.bash import write_bash_completion
 from stgit.completion.fish import write_fish_completion
 
@@ -51,7 +50,7 @@ def main():
     if args:
         op.error('Wrong number of arguments')
     if options.stgit_version:
-        print(stgit.version.get_version())
+        print(get_version())
     elif options.asciidoc:
         argparse.write_asciidoc(stgit.main.commands[options.asciidoc], sys.stdout)
     elif options.commands:
@@ -62,7 +61,7 @@ def main():
             commands.get_commands(allow_cached=False), sys.stdout
         )
     elif options.py_cmd_list:
-        commands.py_commands(commands.get_commands(allow_cached=False), sys.stdout)
+        commands.write_cmdlist_py(sys.stdout)
     elif options.bash_completion:
         write_bash_completion(sys.stdout)
     elif options.fish_completion:
