@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 __copyright__ = """
 Copyright (C) 2005, Catalin Marinas <catalin.marinas@gmail.com>
 
@@ -16,3 +13,12 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, see http://www.gnu.org/licenses/.
 """
+
+
+def get_version():
+    # Importing stgit._version will determine the version by running git
+    # commands when stgit is run from its own git repository. That expense
+    # is avoided by only doing the import when get_version() is called.
+    import stgit._version
+
+    return stgit._version.__version__
