@@ -404,7 +404,7 @@ def func(parser, options, args):
         branch_names = sorted(
             ref.replace('refs/heads/', '', 1)
             for ref in repository.refs
-            if ref.startswith('refs/heads/') and not ref.endswith('.stgit')
+            if ref.startswith('refs/heads/')
         )
 
         if branch_names:
@@ -428,7 +428,7 @@ def func(parser, options, args):
         try:
             stack = repository.get_stack(branch_name)
         except StackException:
-            raise CmdException('Branch "%s" is not controlled by StGIT' % branch_name)
+            raise CmdException('Branch "%s" is not controlled by StGit' % branch_name)
 
         out.start('Protecting branch "%s"' % branch_name)
         stack.protected = True
@@ -465,7 +465,7 @@ def func(parser, options, args):
         try:
             stack = repository.get_stack(branch_name)
         except StackException:
-            raise CmdException('Branch "%s" is not controlled by StGIT' % branch_name)
+            raise CmdException('Branch "%s" is not controlled by StGit' % branch_name)
 
         out.info('Unprotecting branch "%s"' % branch_name)
         stack.protected = False
