@@ -20,8 +20,8 @@ from stgit.out import out
 from stgit.run import Run, RunException
 from stgit.utils import (
     EditorException,
-    add_trailer,
-    edit_bytes,
+    add_trailers,
+    edit_string,
     get_hook,
     run_hook_on_bytes,
     strip_prefix,
@@ -322,6 +322,24 @@ def post_rebase(stack, applied, cmd_name, check_merged):
     return trans.run(iw)
 
 
+def delete_patches(stack, iw, patches):
+    def allow_conflicts(trans):
+        # Allow conflicts if the topmost patch stays the same.
+        if stack.patchorder.applied:
+            return trans.applied and trans.applied[-1] == stack.patchorder.applied[-1]
+        else:
+            return not trans.applied
+
+    trans = StackTransaction(stack, 'delete', allow_conflicts=allow_conflicts)
+    try:
+        to_push = trans.delete_patches(lambda pn: pn in patches)
+        for pn in to_push:
+            trans.push_patch(pn, iw)
+    except TransactionHalted:
+        pass
+    return trans.run(iw)
+
+
 #
 # Patch description/e-mail/diff parsing
 #
@@ -343,7 +361,7 @@ def __split_descr_diff(string):
 
     if m:
         desc = string[: m.start()]
-        diff = string[m.start() :]
+        diff = string.split(m.group(), 1)[1]
     else:
         desc = string
         diff = b''
@@ -351,10 +369,14 @@ def __split_descr_diff(string):
     return desc, diff
 
 
-def __parse_description(descr):
-    """Parse the patch description for author information."""
+def __parse_description(descr, fail_on_empty_description):
+    """Parse the patch description for patch and author information."""
     subject = ''
-    authname = authemail = authdate = None
+    patch_name = authname = authemail = authdate = None
+
+    descr = '\n'.join(strip_comments(descr)).strip()
+    if fail_on_empty_description and not descr:
+        raise CmdException('Aborting edit due to empty patch description')
 
     descr_lines = [line.rstrip() for line in descr.splitlines()]
 
@@ -365,6 +387,11 @@ def __parse_description(descr):
     for pos, line in enumerate(descr_lines):
         if not line:
             continue
+        # check for a "Patch" line
+        if re.match(r'\s*patch:', line, re.I):
+            patch_name = re.findall(r'^.*?:(.*)$', line)[0].strip()
+            lasthdr = pos + 1
+            continue
         # check for a "From|Author:" line
         if re.match(r'\s*(?:from|author):\s+', line, re.I):
             auth = re.findall(r'^.*?:\s+(.*)$', line)[0]
@@ -389,13 +416,13 @@ def __parse_description(descr):
     body = ''.join(line[descr_strip:] + '\n' for line in descr_lines[lasthdr:])
     message = subject + '\n' + body
 
-    return (message, authname, authemail, authdate)
+    return (message, patch_name, authname, authemail, authdate)
 
 
-def parse_patch(patch_data, contains_diff):
+def parse_patch(patch_data, contains_diff, fail_on_empty_description=True):
     """Parse patch data.
 
-    Returns (description, authname, authemail, authdate, diff)
+    Returns (description, patch_name, authname, authemail, authdate, diff)
 
     """
     assert isinstance(patch_data, bytes)
@@ -404,13 +431,17 @@ def parse_patch(patch_data, contains_diff):
     else:
         descr = patch_data
         diff = None
-    (descr, authname, authemail, authdate) = __parse_description(
-        decode_utf8_with_latin1(descr)
+    (descr, patch_name, authname, authemail, authdate) = __parse_description(
+        decode_utf8_with_latin1(descr), fail_on_empty_description
     )
 
-    # we don't yet have an agreed place for the creation date.
-    # Just return None
-    return (descr, authname, authemail, authdate, diff)
+    return (descr, patch_name, authname, authemail, authdate, diff)
+
+
+def strip_comments(message):
+    for line in message.splitlines():
+        if not line.startswith('#'):
+            yield line
 
 
 def run_commit_msg_hook(repo, cd, editor_is_used=True):
@@ -437,8 +468,33 @@ def run_commit_msg_hook(repo, cd, editor_is_used=True):
         return cd
 
 
-def update_commit_data(cd, message=None, author=None, sign_str=None, edit=False):
+COMMIT_MESSAGE_INSTRUCTIONS = """
+# Please enter the commit message for your changes. Lines starting
+# with '#' will be ignored.
+#
+# """
+
+COMMIT_MESSAGE_DEMARCATION_LINE = """
+# ------------------------ >8 ------------------------"""
+
+COMMIT_MESSAGE_INSTRUCTIONS_2 = """
+# Do not modify or remove the line above.
+# Everything below it will be ignored.
+"""
+
+
+def _git_status():
+    out = Run('git', 'status').output_lines()
+    # strip out git's "instruction" lines, such as '(use "git add <file>..." to update'
+    return [line for line in out if '(use' not in line]
+
+
+def update_commit_data(
+    repo, cd, message=None, author=None, trailers=None, edit=False, verbose=False
+):
     """Create updated CommitData according to the command line options."""
+    iw = repo.default_iw
+
     # Set the commit message from commandline.
     if message is not None:
         cd = cd.set_message(message)
@@ -448,18 +504,40 @@ def update_commit_data(cd, message=None, author=None, sign_str=None, edit=False)
         cd = cd.set_author(author)
 
     # Add Signed-off-by: or similar.
-    if sign_str is None:
-        sign_str = config.get("stgit.autosign")
-    if sign_str:
+    if not trailers:
+        autosign = config.get("stgit.autosign")
+        if autosign:
+            trailers = [(autosign, None)]
+    if trailers:
         cd = cd.set_message(
-            add_trailer(cd.message_str, sign_str, cd.committer.name, cd.committer.email)
+            add_trailers(
+                cd.message_str, trailers, cd.committer.name, cd.committer.email
+            )
         )
 
     if edit:
+        message_str = cd.message_str
         tmpl = templates.get_template('patchdescr.tmpl')
         if tmpl:
-            cd = cd.set_message(cd.message_str + tmpl)
-        cd = cd.set_message(edit_bytes(cd.message, '.stgit-new.txt'))
+            message_str += tmpl
+
+        status = '\n# '.join(_git_status())
+        message_str += COMMIT_MESSAGE_INSTRUCTIONS + status
+        if verbose:
+            # include a diff
+            message_str += (
+                COMMIT_MESSAGE_DEMARCATION_LINE + COMMIT_MESSAGE_INSTRUCTIONS_2
+            )
+            message_str += iw.diff(
+                repo.rev_parse('HEAD').data.tree,
+                binary=False,
+            ).decode('utf-8')
+        new_message = edit_string(message_str, '.stgit-new.txt')
+        new_message = new_message.split(COMMIT_MESSAGE_DEMARCATION_LINE)[0]
+        new_message = '\n'.join(
+            line for line in new_message.splitlines() if not line.startswith('#')
+        )
+        cd = cd.set_message(new_message)
 
     return cd
 
