@@ -123,9 +123,7 @@ def func(parser, options, args):
     if num == 0:
         raise CmdException('No patches applied')
 
-    zpadding = len(str(num))
-    if zpadding < 2:
-        zpadding = 2
+    zpadding = max(len(str(num)), 2)
 
     # get the template
     if options.template:
@@ -142,7 +140,7 @@ def func(parser, options, args):
         series = io.open(os.path.join(dirname, 'series'), 'w')
         # note the base commit for this series
         base_commit = stack.base.sha1
-        print('# This series applies on GIT commit %s' % base_commit, file=series)
+        print('# This series applies on Git commit %s' % base_commit, file=series)
 
     for patch_no, pn in enumerate(patches, 1):
         if options.patch:
