@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt, patch_range
 from stgit.commands.common import DirectoryHasRepository, parse_patches
 from stgit.lib import transaction
