@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.argparse import opt
 from stgit.commands.common import CmdException, DirectoryHasRepository
 from stgit.out import out
@@ -41,8 +38,7 @@ directory = DirectoryHasRepository()
 
 
 def func(parser, options, args):
-    """Show the name of the previous patch
-    """
+    """Show the name of the previous patch"""
     if len(args) != 0:
         parser.error('incorrect number of arguments')
 
