@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 __copyright__ = """
 Copyright (C) 2007, Karl Hasselström <kha@treskal.com>
 
