@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
+class ObjectCache:
+    """Cache to ensure only one Python object is created per Git object.
 
+    This reduces memory consumption and makes object comparison very cheap.
 
-class ObjectCache(object):
-    """Cache for Python objects, for making sure that we create only one
-    Python object per git object. This reduces memory consumption and
-    makes object comparison very cheap."""
+    """
 
     def __init__(self, create):
         self.__objects = {}
