@@ -1,3 +1,4 @@
+import json
 import os
 import shutil
 
@@ -8,35 +9,28 @@ from stgit.out import out
 from stgit.run import RunException
 
 # The current StGit metadata format version.
-FORMAT_VERSION = 4
+FORMAT_VERSION = 5
 
 
-def format_version_key(branch):
+def _format_version_key(branch):
     return 'branch.%s.stgit.stackformatversion' % branch
 
 
-def mkdir_file(filename, mode, encoding='utf-8'):
-    """Opens filename with the given mode, creating the directory it's
-    in if it doesn't already exist."""
-    os.makedirs(os.path.dirname(filename), exist_ok=True)
-    return open(filename, mode, encoding=encoding)
-
-
-def read_strings(filename, encoding='utf-8'):
+def _read_strings(filename):
     """Reads the lines from a file"""
-    with open(filename, encoding=encoding) as f:
+    with open(filename, encoding='utf-8') as f:
         return [line.strip() for line in f.readlines()]
 
 
-def read_string(filename, encoding='utf-8'):
+def _read_string(filename):
     """Reads the first line from a file"""
-    with open(filename, encoding=encoding) as f:
+    with open(filename, encoding='utf-8') as f:
         return f.readline().strip()
 
 
-def create_empty_file(name):
-    """Creates an empty file"""
-    mkdir_file(name, 'w+').close()
+def _try_rm(f):
+    if os.path.exists(f):
+        os.remove(f)
 
 
 def update_to_current_format_version(repository, branch):
@@ -50,10 +44,20 @@ def update_to_current_format_version(repository, branch):
 
     patches_dir = os.path.join(repository.directory, 'patches')
     branch_dir = os.path.join(patches_dir, branch)
-    old_format_key = format_version_key(branch)
+    old_format_key = _format_version_key(branch)
     older_format_key = 'branch.%s.stgitformatversion' % branch
 
     def get_meta_file_version():
+        """Get format version from the ``meta`` file in the stack log branch."""
+        new_version = get_stack_json_file_version()
+        if new_version is not None:
+            return new_version
+
+        old_version = get_old_meta_file_version()
+        if old_version is not None:
+            return old_version
+
+    def get_old_meta_file_version():
         """Get format version from the ``meta`` file in the stack log branch."""
         stack_ref = 'refs/heads/%s.stgit:meta' % branch
         try:
@@ -71,6 +75,25 @@ def update_to_current_format_version(repository, branch):
         else:
             return None
 
+    def get_stack_json_file_version():
+        stack_ref = 'refs/stacks/%s:stack.json' % branch
+        try:
+            data = (
+                repository.run(['git', 'show', stack_ref])
+                .decoding('utf-8')
+                .discard_stderr()
+                .raw_output()
+            )
+        except RunException:
+            return None
+
+        try:
+            stack_json = json.loads(data)
+        except json.JSONDecodeError:
+            return None
+        else:
+            return stack_json.get('version')
+
     def get_format_version():
         """Return the integer format version number.
 
@@ -112,23 +135,15 @@ def update_to_current_format_version(repository, branch):
         out.info('Upgraded branch %s to format version %d' % (branch, v))
         config.set(old_format_key, '%d' % v)
 
-    def mkdir(d):
-        if not os.path.isdir(d):
-            os.makedirs(d)
-
-    def rm(f):
-        if os.path.exists(f):
-            os.remove(f)
-
     def rm_ref(ref):
         if repository.refs.exists(ref):
             repository.refs.delete(ref)
 
     # Update 0 -> 1.
     if get_format_version() == 0:
-        mkdir(os.path.join(branch_dir, 'trash'))
+        os.makedirs(os.path.join(branch_dir, 'trash'), exist_ok=True)
         patch_dir = os.path.join(branch_dir, 'patches')
-        mkdir(patch_dir)
+        os.makedirs(patch_dir, exist_ok=True)
         refs_base = 'refs/patches/%s' % branch
         with open(os.path.join(branch_dir, 'unapplied')) as f:
             patches = f.readlines()
@@ -139,7 +154,7 @@ def update_to_current_format_version(repository, branch):
             os.rename(os.path.join(branch_dir, patch), os.path.join(patch_dir, patch))
             topfield = os.path.join(patch_dir, patch, 'top')
             if os.path.isfile(topfield):
-                top = read_string(topfield)
+                top = _read_string(topfield)
             else:
                 top = None
             if top:
@@ -154,11 +169,11 @@ def update_to_current_format_version(repository, branch):
     if get_format_version() == 1:
         desc_file = os.path.join(branch_dir, 'description')
         if os.path.isfile(desc_file):
-            desc = read_string(desc_file)
+            desc = _read_string(desc_file)
             if desc:
                 config.set('branch.%s.description' % branch, desc)
-            rm(desc_file)
-        rm(os.path.join(branch_dir, 'current'))
+            _try_rm(desc_file)
+        _try_rm(os.path.join(branch_dir, 'current'))
         rm_ref('refs/bases/%s' % branch)
         set_format_version_in_config(2)
 
@@ -173,16 +188,17 @@ def update_to_current_format_version(repository, branch):
     # compatibility with the new infrastructure. The changes here do not
     # affect the compatibility with the old infrastructure (format version 2)
     if get_format_version() == 3:
+        os.makedirs(branch_dir, exist_ok=True)
         hidden_file = os.path.join(branch_dir, 'hidden')
         if not os.path.isfile(hidden_file):
-            create_empty_file(hidden_file)
+            open(hidden_file, 'w+', encoding='utf-8').close()
 
         applied_file = os.path.join(branch_dir, 'applied')
         unapplied_file = os.path.join(branch_dir, 'unapplied')
 
-        applied = read_strings(applied_file)
-        unapplied = read_strings(unapplied_file)
-        hidden = read_strings(hidden_file)
+        applied = _read_strings(applied_file)
+        unapplied = _read_strings(unapplied_file)
+        hidden = _read_strings(hidden_file)
 
         state_ref = 'refs/heads/%s.stgit' % branch
 
@@ -257,6 +273,77 @@ def update_to_current_format_version(repository, branch):
             pass
         out.info('Upgraded branch %s to format version %d' % (branch, 4))
 
+    # Metadata moves from refs/heads/<branch>.stgit to refs/stacks/<branch>.
+    # Also, metadata file format is JSON instead of custom format.
+    if get_format_version() == 4:
+        old_state_ref = 'refs/heads/%s.stgit' % branch
+        old_state = repository.refs.get(old_state_ref)
+        old_meta = old_state.data.tree.data['meta'][1].data.bytes
+        lines = old_meta.decode('utf-8').splitlines()
+        if not lines[0].startswith('Version: 4'):
+            raise StackException('Malformed metadata (expected version 4)')
+
+        parsed = {}
+        key = None
+        for line in lines:
+            if line.startswith(' '):
+                assert key is not None
+                parsed[key].append(line.strip())
+            else:
+                key, val = [x.strip() for x in line.split(':', 1)]
+                if val:
+                    parsed[key] = val
+                else:
+                    parsed[key] = []
+
+        head = repository.refs.get('refs/heads/%s' % branch)
+
+        new_meta = dict(
+            version=5,
+            prev=parsed['Previous'],
+            head=head.sha1,
+            applied=[],
+            unapplied=[],
+            hidden=[],
+            patches=dict(),
+        )
+
+        if parsed['Head'] != new_meta['head']:
+            raise StackException('Unexpected head mismatch')
+
+        for patch_list_name in ['Applied', 'Unapplied', 'Hidden']:
+            for entry in parsed[patch_list_name]:
+                pn, sha1 = [x.strip() for x in entry.split(':')]
+                new_patch_list_name = patch_list_name.lower()
+                new_meta[new_patch_list_name].append(pn)
+                new_meta['patches'][pn] = dict(oid=sha1)
+
+        meta_bytes = json.dumps(new_meta, indent=2).encode('utf-8')
+
+        tree = repository.commit(
+            TreeData(
+                {
+                    'stack.json': repository.commit(BlobData(meta_bytes)),
+                    'patches': old_state.data.tree.data['patches'],
+                }
+            )
+        )
+
+        repository.refs.set(
+            'refs/stacks/%s' % branch,
+            repository.commit(
+                CommitData(
+                    tree=tree,
+                    message='stack upgrade to version 5',
+                    parents=[head],
+                )
+            ),
+            'stack upgrade to v5',
+        )
+
+        repository.refs.delete(old_state_ref)
+        out.info('Upgraded branch %s to format version %d' % (branch, 5))
+
     # Make sure we're at the latest version.
     fv = get_format_version()
     if fv not in [None, FORMAT_VERSION]:
