@@ -5,7 +5,7 @@ import sys
 import traceback
 
 import stgit.commands
-from stgit import argparse, run, utils
+from stgit import argparse, get_version, run, utils
 from stgit.compat import environ_get, fsdecode_utf8
 from stgit.config import config
 from stgit.out import out
@@ -53,9 +53,6 @@ def append_alias_commands(cmd_list):
         cmd_list.append((name, CommandAlias(name, command), 'Alias commands', command))
 
 
-#
-# The commands map
-#
 class Commands(dict):
     """Commands class. It performs on-demand module loading"""
 
@@ -66,18 +63,20 @@ class Commands(dict):
         if not candidates:
             out.error(
                 'Unknown command: %s' % key,
-                'Try "%s help" for a list of supported commands' % prog,
+                'Try "%s help" for a list of supported commands' % sys.argv[0],
             )
             sys.exit(utils.STGIT_GENERAL_ERROR)
-        elif len(candidates) > 1:
+        elif len(candidates) == 1:
+            return candidates[0]
+        elif key in candidates:
+            return key
+        else:
             out.error(
                 'Ambiguous command: %s' % key,
                 'Candidates are: %s' % ', '.join(candidates),
             )
             sys.exit(utils.STGIT_GENERAL_ERROR)
 
-        return candidates[0]
-
     def __getitem__(self, key):
         cmd_mod = self.get(key) or self.get(self.canonical_cmd(key))
         if is_cmd_alias(cmd_mod):
@@ -103,11 +102,8 @@ def print_help():
 
 
 def _main():
-    global prog
-
-    sys.argv = list(map(fsdecode_utf8, sys.argv))
-
-    prog = os.path.basename(sys.argv[0])
+    sys.argv[:] = list(map(fsdecode_utf8, sys.argv))
+    prog = sys.argv[0] = 'stg'
 
     if len(sys.argv) < 2:
         print('usage: %s <command>' % prog, file=sys.stderr)
@@ -138,9 +134,7 @@ def _main():
             print_help()
         sys.exit(utils.STGIT_SUCCESS)
     if cmd in ['-v', '--version', 'version']:
-        from stgit.version import get_version
-
-        print('Stacked GIT %s' % get_version())
+        print('Stacked Git %s' % get_version())
         os.system('git --version')
         print('Python version %s' % sys.version)
         sys.exit(utils.STGIT_SUCCESS)
@@ -161,10 +155,8 @@ def _main():
 
     # These modules are only used from this point onwards and do not
     # need to be imported earlier
-    try:
-        from configparser import NoSectionError, ParsingError
-    except ImportError:
-        from ConfigParser import NoSectionError, ParsingError
+    from configparser import NoSectionError, ParsingError
+
     from stgit.config import config_setup
     from stgit.exception import StgException
     from stgit.lib.git import MergeConflictException
