@@ -23,6 +23,11 @@ test_expect_success 'Initialize StGit stack with three patches' '
     stg uncommit -n 3
 '
 
+test_expect_success 'Invalid number of patches to redo' '
+    command_error stg redo -n0 2>&1 |
+    grep -e "Bad number of undos to redo"
+'
+
 cat > expected.txt <<EOF
 000
 111
