@@ -32,10 +32,19 @@ auth () { git log -n 1 --pretty=format:"%an, %ae" $1 ; }
 adate () { git log -n 1 --pretty=format:%ai $1 ; }
 
 write_script diffedit <<EOF
-sed 's/empty-patch/Empty Patch/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+echo "" > "\$1"
+EOF
+test_expect_success 'Empty editor aborts edit' '
+    EDITOR=./diffedit command_error stg edit 2>&1 |
+    grep -e "Aborting edit due to empty patch description"
+'
+rm -f diffedit
+
+write_script diffedit <<EOF
+sed 's/Empty patch/Empty Patch/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
 EOF
 test_expect_success 'Edit new patch with no diff' '
-    stg new -m empty-patch &&
+    stg new -m "Empty patch" &&
     test_when_finished stg delete empty-patch &&
     EDITOR=./diffedit stg edit -d &&
     test "$(msg HEAD)" = "Empty Patch"
@@ -83,8 +92,13 @@ test_expect_success 'Set patch message with --file -' '
     test "$(msg HEAD)" = "Pride and Prejudice"
 '
 
-( printf 'From: A Ú Thor <author@example.com>\nDate: <omitted>'
-  printf '\n\nPride and Prejudice\n' ) > expected-tmpl
+( printf 'Patch: p2\nFrom: A Ú Thor <author@example.com>\nDate: <omitted>'
+  printf '\n\nPride and Prejudice\n'
+  printf '\n# Everything here is editable! You can modify the patch name, author,'
+  printf '\n# date, commit message, and the diff (if --diff was given).'
+  printf "\n# Lines starting with '#' will be ignored, and an empty message"
+  printf '\n# aborts the edit.\n'
+) > expected-tmpl
 omit_date () { sed "s/^Date:.*$/Date: <omitted>/" ; }
 
 test_expect_success 'Save template to file' '
@@ -121,7 +135,7 @@ test_expect_success 'Edit commit message interactively (vi)' '
     unset EDITOR
     m=$(msg HEAD) &&
     PATH=.:$PATH stg edit p2 &&
-    test "$(msg HEAD)" = "$m/vi"
+    test "$(msg HEAD)" = "$m//vi"
 '
 
 mkeditor e1
@@ -129,14 +143,14 @@ test_expect_success 'Edit commit message interactively (EDITOR)' '
     m=$(msg HEAD) &&
     EDITOR=./e1 PATH=.:$PATH stg edit p2 &&
     echo $m && echo $(msg HEAD) &&
-    test "$(msg HEAD)" = "$m/e1"
+    test "$(msg HEAD)" = "$m//e1"
 '
 
 mkeditor e2
 test_expect_success 'Edit commit message interactively (VISUAL)' '
     m=$(msg HEAD) &&
     VISUAL=./e2 EDITOR=./e1 PATH=.:$PATH stg edit p2 &&
-    test "$(msg HEAD)" = "$m/e2"
+    test "$(msg HEAD)" = "$m//e2"
 '
 
 mkeditor e3
@@ -144,7 +158,7 @@ test_expect_success 'Edit commit message interactively (core.editor)' '
     m=$(msg HEAD) &&
     git config core.editor e3 &&
     VISUAL=./e2 EDITOR=./e1 PATH=.:$PATH stg edit p2 &&
-    test "$(msg HEAD)" = "$m/e3"
+    test "$(msg HEAD)" = "$m//e3"
 '
 
 mkeditor e4
@@ -152,14 +166,14 @@ test_expect_success 'Edit commit message interactively (stgit.editor)' '
     m=$(msg HEAD) &&
     git config stgit.editor e4 &&
     VISUAL=./e2 EDITOR=./e1 PATH=.:$PATH stg edit p2 &&
-    test "$(msg HEAD)" = "$m/e4"
+    test "$(msg HEAD)" = "$m//e4"
 '
 
 mkeditor e5
 test_expect_success 'Edit commit message interactively (GIT_EDITOR)' '
     m=$(msg HEAD) &&
     GIT_EDITOR=./e5 VISUAL=./e2 EDITOR=./e1 PATH=.:$PATH stg edit p2 &&
-    test "$(msg HEAD)" = "$m/e5"
+    test "$(msg HEAD)" = "$m//e5"
 '
 
 rm -f vi e1 e2 e3 e4 e5
@@ -169,7 +183,7 @@ git config --unset stgit.editor
 mkeditor twoliner
 test_expect_success 'Both noninterative and interactive editing' '
     EDITOR=./twoliner stg edit -e -m "oneliner" p2 &&
-    test "$(msg HEAD)" = "oneliner/twoliner"
+    test "$(msg HEAD)" = "oneliner//twoliner"
 '
 rm -f twoliner
 
@@ -182,23 +196,82 @@ test_expect_success 'Edit patch diff' '
 '
 rm -f diffedit
 
-test_expect_success 'Sign a patch' '
-    m=$(msg HEAD) &&
-    stg edit --sign p2 &&
-    test "$(msg HEAD)" = "$m//Signed-off-by: C Ó Mitter <committer@example.com>"
+write_script diffedit <<EOF
+sed 's/+1,4/+1,5/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit patch diff which fails to apply' '
+    EDITOR=./diffedit stg edit -d p2 2>&1 |
+    grep -e "Edited patch did not apply." &&
+    test "$(grep 111 foo)" = "111YY" &&
+    test_file_not_empty .stgit-failed.patch
 '
+rm -f diffedit
+rm -f .stgit-failed.patch
 
-test_expect_success 'Acknowledge a patch' '
-    m=$(msg HEAD^) &&
-    stg edit --ack p1 &&
-    test "$(msg HEAD^)" = "$m//Acked-by: C Ó Mitter <committer@example.com>"
+write_script diffedit <<EOF
+sed 's/Patch: p2/Patch: p2-new/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit patch name of top patch' '
+    EDITOR=./diffedit stg edit -d &&
+	test "$(stg top)" = "p2-new" &&
+    test "$(stg series -c)" = "3" &&
+    stg rename p2-new p2
 '
+rm -f diffedit
 
-test_expect_success 'Review a patch' '
-    m=$(msg HEAD^) &&
-    stg edit --review p1 &&
-    test "$(msg HEAD^)" = "$m/Reviewed-by: C Ó Mitter <committer@example.com>"
+write_script diffedit <<EOF
+sed 's/Patch: p1/Patch: p1-new/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit patch name of non-top applied patch' '
+    EDITOR=./diffedit stg edit -d p1 &&
+	test "$(stg series --noprefix | head -n 1)" = "p1-new" &&
+    test "$(stg series -c)" = "3" &&
+    stg rename p1-new p1
 '
+rm -f diffedit
+
+write_script diffedit <<EOF
+sed 's/Patch: p3/Patch: p3-new/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit patch name of non-applied patch' '
+    EDITOR=./diffedit stg edit -d p3 &&
+	test "$(stg series --noprefix --unapplied)" = "p3-new" &&
+    test "$(stg series -c)" = "3" &&
+    stg rename p3-new p3
+'
+rm -f diffedit
+
+write_script diffedit <<EOF
+sed 's/Patch: p4/Patch: p4-new/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Edit patch name of hidden patch' '
+    EDITOR=./diffedit stg edit -d p4 &&
+	test "$(stg series --noprefix --hidden)" = "p4-new" &&
+    stg rename p4-new p4
+'
+rm -f diffedit
+
+write_script diffedit <<EOF
+sed 's/Patch: p2/Patch:/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Clearing the patch name results in a new autogenerated name' '
+    EDITOR=./diffedit stg edit -d &&
+	test "$(stg top)" = "oneliner" &&
+    test "$(stg series -c)" = "3" &&
+    stg rename oneliner p2
+'
+rm -f diffedit
+
+write_script diffedit <<EOF
+sed -e 's/Patch: p2/Patch: p2-new/' -e 's/twoliner/twoliner-new/' "\$1" > "\$1".tmp && mv "\$1".tmp "\$1"
+EOF
+test_expect_success 'Rename patch and edit its diff' '
+    EDITOR=./diffedit stg edit -d &&
+	test "$(stg top)" = "p2-new" &&
+    stg show | grep twoliner-new &&
+    stg rename p2-new p2
+'
+rm -f diffedit
 
 test_expect_success 'Set author' '
     stg edit p2 --author "Jane Austin <jaustin@example.com>" &&
